.. _pycoin.ecdsa:

ECDSA
=====


:mod:`__init__` Module
----------------------------------

.. automodule:: pycoin.ecdsa.__init__
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`Curve` Module
----------------------------------

.. automodule:: pycoin.ecdsa.Curve
    :members:
    :undoc-members:


.. _ecdsa.Generator:

:mod:`Generator` Module
----------------------------------

.. automodule:: pycoin.ecdsa.Generator
    :members:
    :special-members: __mul__
    :undoc-members:
    :show-inheritance:


:mod:`Point` Module
----------------------------------

.. automodule:: pycoin.ecdsa.Point
    :members:
    :special-members: __add__, __mul__, __sub__, __neg__
    :undoc-members:
    :show-inheritance:


:mod:`encrypt` Module
----------------------------------

.. automodule:: pycoin.ecdsa.encrypt
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`intstream` Module
----------------------------------

.. automodule:: pycoin.ecdsa.intstream
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`rfc6979` Module
----------------------------------

.. automodule:: pycoin.ecdsa.rfc6979
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`secp256k1` Module
----------------------------------

.. automodule:: pycoin.ecdsa.secp256k1
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`secp256r1` Module
----------------------------------

.. automodule:: pycoin.ecdsa.secp256r1
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`native.bignum` Module
----------------------------------

.. automodule:: pycoin.ecdsa.native.bignum
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`native.openssl` Module
----------------------------------

.. automodule:: pycoin.ecdsa.native.openssl
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`native.secp256k1` Module
----------------------------------

.. automodule:: pycoin.ecdsa.native.secp256k1
    :members:
    :undoc-members:
    :show-inheritance:
